@@ -80,12 +80,22 @@
     se = .unique_es_subgroups(x, measure)$se,
     ci_lo = .unique_es_subgroups(x, measure)$ci_lo,
     ci_up = .unique_es_subgroups(x, measure)$ci_up,
+    n_sample = sum(x$n_sample),
     n_cases = n_cases,
     n_controls = n_controls,
     mean_cases = NA,
     sd_cases = NA,
     mean_controls = NA,
     sd_controls = NA,
+    mean_pre_cases = NA,
+    sd_pre_cases = NA,
+    mean_pre_controls = NA,
+    sd_pre_controls = NA,
+    mean_change_cases = NA,
+    sd_change_cases = NA,
+    mean_change_controls = NA,
+    sd_change_controls = NA,
+    pre_post_cor = NA,
     sum_N = sum_N,
     n_cases_exp = sum(x$n_cases_exp),
     n_controls_exp = sum(x$n_controls_exp),
@@ -168,12 +178,22 @@
     se = se,
     ci_lo = ci_lo,
     ci_up = ci_up,
+    n_sample = x$n_sample[N_max],
     n_cases = n_cases,
     n_controls = n_controls,
     mean_cases = NA,
     sd_cases = NA,
     mean_controls = NA,
     sd_controls = NA,
+    mean_pre_cases = NA,
+    sd_pre_cases = NA,
+    mean_pre_controls = NA,
+    sd_pre_controls = NA,
+    mean_change_cases = NA,
+    sd_change_cases = NA,
+    mean_change_controls = NA,
+    sd_change_controls = NA,
+    pre_post_cor = NA,
     sum_N = sum_N,
     n_exp = n_exp,
     n_nexp = n_nexp,
@@ -221,11 +241,13 @@
   df_group <- do.call(rbind, lapply(x_mult_group_split, .agg_subgroups, measure))
   df_outcome <- do.call(rbind, lapply(x_mult_outcome_split, .agg_outcomes, measure))
   df_unique <- x_unique[,c('row_index', 'author', 'year', 'multiple_es', 'duplicate',
-                           'value', 'se', 'ci_lo', 'ci_up', 'n_cases', 'n_controls', 'mean_cases',
+                           'value', 'se', 'ci_lo', 'ci_up', 'n_sample', 'n_cases', 'n_controls', 'mean_cases',
                            'sd_cases', 'mean_controls', 'sd_controls',
+                           'mean_pre_cases', 'sd_pre_cases', 'mean_pre_controls','sd_pre_controls',
+                           'mean_change_cases', 'sd_change_cases', 'mean_change_controls', 'sd_change_controls', 'pre_post_cor',
                            'sum_N', 'n_cases_exp', 'n_controls_exp', 'n_cases_nexp', 'n_controls_nexp',
                            'n_exp', 'n_nexp', 'time', 'time_exp', 'time_nexp',
-                           'rob.recoded', 'shared_nexp',
+                            'rob.recoded', 'shared_nexp',
                            'shared_controls', 'thr', 'reverse_es', 'r')]
 
   # 4) we return the merged datasets
